@@ -42,7 +42,7 @@ sub init
     while (<Font::TTF::Hhea::DATA>)
     {
         ($k, $v, $c) = TTF_Init_Fields($_, $c);
-        next unless $k ne "";
+        next unless defined $k && $k ne "";
         $fields{$k} = $v;
     }
 }
@@ -142,7 +142,7 @@ None known
 
 =head1 AUTHOR
 
-Martin Hosken L<Martin_Hosken@sil.org>. See L<Font::TTF::Font> for copyright and
+Martin Hosken Martin_Hosken@sil.org. See L<Font::TTF::Font> for copyright and
 licensing.
 
 =cut
@@ -160,5 +160,5 @@ xMaxExtent, s
 caretSlopeRise, s
 caretSlopeRun, s
 metricDataFormat, +10s
-numberOfHMetrics, s
+numberOfHMetrics, S
 
